/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- */
/*          EXIFPROBE - TIFF/JPEG/EXIF image file probe               */
/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- */
/* Copyright (C) 2002 by Duane H. Hesser. All rights reserved.        */
/*                                                                    */
/* See the file LICENSE.EXIFPROBE for terms of use.                   */
/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- */

/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- */
/* @(#) $Id: defs.h,v 1.19 2003/05/05 16:11:40 alex Exp $" */
/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- */

/* General defines, used everywhere                                   */

#ifndef DEFS_INCLUDED
#define DEFS_INCLUDED

#define HERE    (unsigned long)0xffffffff

#define FNULL   (FILE *)0
#define CNULL   (char *)0
#define MAXBUFLEN   8192
#define MAXIFDS     1024
#define MAXINDENT   80
#define NOINDENT    0
#define SUBINDENT   2
#define ADDRWIDTH   8
#define DUMPALL     0xffffffffUL


#define HEXTAGNO                0x00000001UL
#define DECTAGNO                0x00000002UL
#define HEXVALUE                0x00000010UL
#define DECVALUE                0x00000020UL
#define HEXOFFSET               0x00000100UL
#define DECOFFSET               0x00000200UL
#define TAGNAME                 0x00001000UL
#define TYPE                    0x00002000UL

#define HEXADDRESS              0x00010000UL
#define DECADDRESS              0x00020000UL
#define SECTION                 0x00040000UL
#define SEGMENT                 0x00080000UL

#define APP_ENTRY               0x00100000UL
#define MAKERDUMP               0x00200000UL
#define APPNDUMP                0x00400000UL

#ifdef COLOR
#define PCOLOR                  0x01000000UL
#else
#define PCOLOR                  0UL
#endif
#define VALUE_AT_OFFSET         0x02000000UL   
#define RAW_VALUES              0x04000000UL
#define RELOFFSET               0x08000000UL

#define INDENT_AFTER_ADDRESS    0x10000000UL
#define INDENT_BEFORE_ADDRESS   0x20000000UL
#define ASCII_IGNORE_LENGTH     0x40000000UL
#define MULTIVAL_PRINT_ALL      0x80000000UL

#define ENTRY                   0x08003333UL
#define DEF_ENTRY               0x00003323UL

#define PRINT_ENTRY             (Print_options & ENTRY)
#define PRINT_SEGMENT           (Print_options & SEGMENT)
#define PRINT_SECTION           (Print_options & SECTION )
#define PRINT_APPENTRY          (Print_options & APP_ENTRY)
#define PRINT_LIST              ((PRINT_SECTION) == 0)

#define DEFAULT_OPTIONS         (SECTION|SEGMENT|DEF_ENTRY|APP_ENTRY|VALUE_AT_OFFSET|DECADDRESS|HEXADDRESS|PCOLOR|INDENT_AFTER_ADDRESS)
#define REPORT_OPTIONS          (TAGNAME|DECVALUE|PCOLOR|SECTION|SEGMENT|APP_ENTRY|ASCII_IGNORE_LENGTH|INDENT_AFTER_ADDRESS)
#define LIST_OPTIONS            (TAGNAME|DECVALUE|ASCII_IGNORE_LENGTH)
#define HEX_ONLY                0x0010111UL
#define DECIMAL_ONLY            0x0020222UL

#define PRINT_ADDRESS           (Print_options & (HEXADDRESS|DECADDRESS))
#define PRINT_HEX_ADDRESS       (Print_options & HEXADDRESS)
#define PRINT_DEC_ADDRESS       (Print_options & DECADDRESS)
#define PRINT_BOTH_ADDRESS      ((PRINT_ADDRESS) == (HEXADDRESS|DECADDRESS))

#define PRINT_TAGNO             (Print_options & (HEXTAGNO|DECTAGNO))
#define PRINT_HEX_TAGNO         (Print_options & HEXTAGNO)
#define PRINT_DEC_TAGNO         (Print_options & DECTAGNO)
#define PRINT_BOTH_TAGNO        ((PRINT_TAGNO) == (HEXTAGNO|DECTAGNO))


#define PRINT_VALUE             (Print_options & (HEXVALUE|DECVALUE))
#define PRINT_HEX_VALUE         (Print_options & HEXVALUE)
#define PRINT_DEC_VALUE         (Print_options & DECVALUE)
#define PRINT_BOTH_VALUE        ((PRINT_VALUE) == (HEXVALUE|DECVALUE))

#define PRINT_OFFSET            (Print_options & (HEXOFFSET|DECOFFSET))
#define PRINT_HEX_OFFSET        (Print_options & HEXOFFSET)
#define PRINT_DEC_OFFSET        (Print_options & DECOFFSET)
#define PRINT_BOTH_OFFSET       ((PRINT_OFFSET) == (HEXOFFSET|DECOFFSET))


#define PRINT_TAGNAME           (Print_options & TAGNAME)
#define PRINT_TYPE              (Print_options & TYPE)

#define PRINT_INDENT_BEFORE_ADDRESS (Print_options & INDENT_BEFORE_ADDRESS)
#define PRINT_INDENT_AFTER_ADDRESS  (Print_options & INDENT_AFTER_ADDRESS)
#define PRINT_INDENT                (Print_options & (INDENT_BEFORE_ADDRESS|INDENT_AFTER_ADDRESS))
#define PRINT_RAW_VALUES            (Print_options & RAW_VALUES)
#define PRINT_ENTRY_RELOFFSET       (Print_options & RELOFFSET)
#define PRINT_VALUE_AT_OFFSET          (Print_options & VALUE_AT_OFFSET)
#define PRINT_ASCII_IGNORE_LENGTH   (Print_options & ASCII_IGNORE_LENGTH)
#define PRINT_MAKERDUMP             (Print_options & MAKERDUMP)
#define PRINT_APPNDUMP              (Print_options & APPNDUMP)
#define PRINT_MULTIVAL_ALL          (Print_options & MULTIVAL_PRINT_ALL)
#define USE_COLOR                   (Print_options & PCOLOR)
#define PREFIX                      ""

#define UNKNOWN_TYPE        0
#define PRIMARY_TYPE        1
#define THUMBNAIL_TYPE      2
#define PAGE_TYPE           3
#define MASK_TYPE           4

#define UNKNOWN     "unknown"
#define PRIMARY     "primary image"
#define THUMBNAIL   "thumbnail"
#define PAGE        "image page"
#define MASK        "image mask"

#define TAGWIDTH    31
#define PREFIXLEN   5
#define IDWIDTH     31

/* IFD types so Interop and GPS tagnames can be handled               */
#define TIFF_IFD    0
#define TIFF_SUBIFD 1
#define EXIF_IFD    2
#define INTEROP_IFD 3
#define GPS_IFD     4
#define MAKER_IFD   5

#ifdef COLOR

/* numerical values for ANSI color print sequences                    */
#define GREEN       32  /* "\033[32m"                                 */
#define HI_GREEN    92  /* "\033[92m"                                 */
#define BLUE        34  /* "\033[34m"                                 */
#define HI_BLUE     94  /* "\033[94m"                                 */
#define RED         31  /* "\033[31m"                                 */
#define HI_RED      91  /* "\033[91m"                                 */
#define MAGENTA     35  /* "\033[35m"                                 */

#define BOLD_BLACK  90  /* "\033[90m"                                 */

#define BG_WHITE    47  /* "\033[47m"                                 */
#define BG_HI_WHITE 107 /* "\033[107m"                                */
#define END_COLOR   0   /* "\033[m"                                   */

#define STARTCOLOR(color)   pushcolor(color)
#define STOPCOLOR           popcolor()

#define IM_COLOR        BOLD_BLACK
#define EXIF_COLOR      MAGENTA
#define GPS_COLOR       HI_RED
#define MAKER_COLOR     HI_BLUE
#define INTEROP_COLOR   GREEN
#define JPEG_COLOR      BOLD_BLACK
#define UNCERTAIN_COLOR BOLD_BLACK

#else
#define NULLSTRING  ""
#define GREEN       0
#define HI_GREEN    0
#define BLUE        0
#define HI_BLUE     0
#define RED         0
#define HI_RED      0

#define BOLD_BLACK  0

#define BG_WHITE    0
#define BG_HI_WHITE 0
#define END_COLOR   0   

#define STARTCOLOR(color)
#define STOPCOLOR

#define IM_COLOR        0
#define MAKER_COLOR     0
#define EXIF_COLOR      0
#define GPS_COLOR       0
#define INTEROP_COLOR   0
#define JPEG_COLOR      0

#endif  /* COLOR */

#endif  /* DEFS_INCLUDED */
